Crate solderium

Crate solderium 

Simple Rust library for merging directories using symlinks

Currently supports only Unix-like operating systems

Enums

Overwrite
Represents the type of action, that takes place when an existing path is to be replaced by a symlink.

Functions

generate_symlinks
Generate symlinks pointing to the source directory content in the target directory.